@@ -105,8 +105,8 @@ struct steve_state {
 	int retval{0};
 	const char *dev_name{"steve"};
 	bool verbose;
-	uint64_t jobs;
-	uint64_t min_jobs{1};
+	int64_t jobs;
+	int64_t min_jobs{1};
 	int64_t per_process_limit;
 	double max_load_avg{-1};  /* < 0 implies no load average */
 	double load_avg;
@@ -785,7 +785,7 @@ static void steve_ioctl(
 			steve_wake_waiters(state);
 			break;
 		case STEVE_IOC_SET_MIN_JOBS:
-			if (static_cast<uint64_t>(val) > state->jobs) {
+			if (val > state->jobs) {
 				fuse_reply_err(req, EINVAL);
 				return;
 			}
